function x = secant(func,x0,param,crit,maxit);
%secant.m   Programa para resolver un sistema de ecuaciones simultaneas.
%         x=secant(func,x0,param,crit,maxit) usa el metodo de secante
%         para resolver el siguiente sistema:
%
%                        f1(z1,z2,...zn)=0
%                        f2(z1,z2,...zn)=0                (*)
%                          :           :
%                        fn(z1,z2,...zn)=0
%
%         en donde x=[z1,z2,...,zn]' es el vector que resuelve (*).
%			 Para usar esta funcin, debe especificarse func que es un string
%         con el nombre de un archivo .m que contiene la funcion f. En caso
%         necesario, puede usarse el vector param para incluir parametros 
%         adicionales de dicha funcion.
%         Los argumentos x0, crit, and maxit son el guess inicial para x,
%         el criterio de convergencia (tolerancia) y el numero maximo de
%         iteraciones permitidas.
%
del = diag(max(abs(x0)*1e-4,1e-8));
n   = length(x0);
for i=1:maxit
  	f = feval(func,x0,param);
  	for j=1:n
    	J(:,j) = (f-feval(func,x0-del(:,j),param))/del(j,j);
  	end;
  	x=x0-inv(J)*f;
  	if norm(x-x0)<crit 
    	break 
  	end
  	x0=x;
end
if i>=maxit 
   sprintf('WARNING: Numero maximo de %g iteraciones alcanzado',maxit)
end
